{% extends 'oscar/checkout/preview.html' %}
{% load currency_filters %}

{% block payment_method %}
<div class="span6">
	<div class="sub-header">
		<h2>Payment</h2>
	</div>
	<div class="well well-success">
		<p>{{ order_total.incl_tax|currency }} will be debited from your bankcard.</p>
		<div class="alert-actions">
			<a href="{% url 'checkout:payment-details' %}" class="btn">Change payment details</a>
		</div>
	</div>
</div>
{% endblock %}

{% block place_order %}
<h3>Please review the information below, then click "Place Order"</h3>
<form method="post" action="{% url 'checkout:preview' %}">
	{% csrf_token %}

	<div style="display:none">
		<input type="hidden" name="action" value="place_order" />
		{{ stripe_token_form.as_p }}
	</div>

    <div class="form-actions">
        <button id='place-order' type="submit" value="Place order" class="pull-right btn btn-primary btn-large js-disable-on-click">Place order</button>
    </div>
</form>
{% endblock place_order %}
